import 'package:flutter/material.dart';
import 'package:flutter_slick/navigation/logic.dart';
import 'package:provider/provider.dart';

class StandardTextField extends StatefulWidget {
  final String? initialValue;
  final FormFieldValidator<String>? validator;
  final int? minLines;
  final int? maxLines;
  final int? maxLength;
  final TextInputAction? textInputAction;
  final FocusNode? focusNode;
  final Function()? onEditingComplete;
  final TextEditingController? controller;
  final bool enabled;
  final bool autofocus;
  final String labelText;
  final Function(String?) onChanged;
  final GestureTapCallback? onTap;
  final Iterable<String>? autofillHints;

  const StandardTextField({
    super.key,
    this.initialValue,
    this.validator,
    this.minLines,
    this.maxLines,
    this.maxLength,
    this.focusNode,
    this.textInputAction,
    this.onEditingComplete,
    this.controller,
    this.enabled = true,
    this.autofocus = false,
    required this.labelText,
    required this.onChanged,
    this.onTap,
    this.autofillHints = const [],
  });

  @override
  State<StandardTextField> createState() => _StandardTextFieldState();
}

class _StandardTextFieldState extends State<StandardTextField> {
  String? _currentValue;

  @override
  void initState() {
    super.initState();
    _currentValue = widget.initialValue;
  }

  @override
  Widget build(BuildContext context) {
    return TextFormField(
      initialValue: widget.initialValue,
      onChanged: (value) {
        _currentValue = value;
        widget.onChanged(value);
      },
      validator: widget.validator,
      keyboardType: TextInputType.text,
      decoration: InputDecoration(
        enabled: widget.enabled,
        labelText: widget.labelText,
      ),
      minLines: widget.minLines,
      maxLines: widget.maxLines,
      maxLength: widget.maxLength,
      autofocus: widget.autofocus,
      focusNode: widget.focusNode,
      textInputAction: widget.textInputAction,
      onEditingComplete: () {
        if (_currentValue != widget.initialValue) {
          Provider.of<NavigationLogic>(context, listen: false).setDirty();
        }
        if (widget.onEditingComplete != null) {
          widget.onEditingComplete!();
        }
      },
      controller: widget.controller,
      onTap: widget.onTap,
      autofillHints: widget.autofillHints,
    );
  }
}
